@@ -22,23 +22,9 @@
  */
 
 #include <lsmmathmlenums.h>
+#include <lsmtraits.h>
 #include <string.h>
 
-static unsigned int
-lsm_mathml_value_from_string (const char *string, const char **strings, unsigned int n_strings)
-{
-	int i;
-
-	if (string == NULL)
-		return 0;
-
-	for (i = 0; i < n_strings; i++)
-		if (strcmp (string, strings[i]) == 0)
-			return i;
-
-	return 0;
-}
-
 static const char *lsm_mathml_mode_strings[] = {
 	"display",
 	"inline"
@@ -47,14 +33,17 @@ static const char *lsm_mathml_mode_strings[] = {
 const char *
 lsm_mathml_mode_to_string (LsmMathmlMode mode)
 {
-	return lsm_mathml_mode_strings[CLAMP (mode, 0, LSM_MATHML_MODE_INLINE)];
+	if (mode < 0 || mode > LSM_MATHML_MODE_INLINE)
+		return NULL;
+
+	return lsm_mathml_mode_strings[mode];
 }
 
 LsmMathmlMode
 lsm_mathml_mode_from_string (const char *string)
 {
-	return lsm_mathml_value_from_string (string, lsm_mathml_mode_strings,
-					  G_N_ELEMENTS (lsm_mathml_mode_strings));
+	return lsm_enum_value_from_string (string, lsm_mathml_mode_strings,
+					   G_N_ELEMENTS (lsm_mathml_mode_strings));
 }
 
 static const char *lsm_mathml_display_strings[] = {
@@ -65,18 +54,20 @@ static const char *lsm_mathml_display_strings[] = {
 const char *
 lsm_mathml_display_to_string (LsmMathmlDisplay display)
 {
-	return lsm_mathml_display_strings[CLAMP (display, 0, LSM_MATHML_DISPLAY_INLINE)];
+	if (display < 0 || display > LSM_MATHML_DISPLAY_INLINE)
+		return NULL;
+
+	return lsm_mathml_display_strings[display];
 }
 
 LsmMathmlDisplay
 lsm_mathml_display_from_string (const char *string)
 {
-	return lsm_mathml_value_from_string (string, lsm_mathml_display_strings,
-					  G_N_ELEMENTS (lsm_mathml_display_strings));
+	return lsm_enum_value_from_string (string, lsm_mathml_display_strings,
+					   G_N_ELEMENTS (lsm_mathml_display_strings));
 }
 
 static const char *lsm_mathml_space_name_strings[] = {
-	"errormathspace",
 	"veryverythinmathspace",
 	"verythinmathspace",
 	"thinmathspace",
@@ -90,14 +81,17 @@ static const char *lsm_mathml_space_name_strings[] = {
 const char *
 lsm_mathml_space_name_to_string (LsmMathmlSpaceName space_name)
 {
-	return lsm_mathml_space_name_strings[CLAMP (space_name, 0, LSM_MATHML_SPACE_NAME_INFINITY)];
+	if (space_name < 0 || space_name > LSM_MATHML_SPACE_NAME_INFINITY)
+		return NULL;
+
+	return lsm_mathml_space_name_strings[space_name];
 }
 
 LsmMathmlSpaceName
 lsm_mathml_space_name_from_string (const char *string)
 {
-	return lsm_mathml_value_from_string (string, lsm_mathml_space_name_strings,
-					  G_N_ELEMENTS (lsm_mathml_space_name_strings));
+	return lsm_enum_value_from_string (string, lsm_mathml_space_name_strings,
+					   G_N_ELEMENTS (lsm_mathml_space_name_strings));
 }
 
 static const char *lsm_mathml_unit_strings[] = {
@@ -116,52 +110,59 @@ static const char *lsm_mathml_unit_strings[] = {
 const char *
 lsm_mathml_unit_to_string (LsmMathmlUnit unit)
 {
-	return lsm_mathml_unit_strings[CLAMP (unit, 0, LSM_MATHML_UNIT_PERCENT)];
+	if (unit < 0 || unit > LSM_MATHML_UNIT_PERCENT)
+		return NULL;
+
+	return lsm_mathml_unit_strings[unit];
 }
 
 LsmMathmlUnit
 lsm_mathml_unit_from_string (const char *string)
 {
-	return lsm_mathml_value_from_string (string, lsm_mathml_unit_strings,
-					  G_N_ELEMENTS (lsm_mathml_unit_strings));
+	return lsm_enum_value_from_string (string, lsm_mathml_unit_strings,
+					   G_N_ELEMENTS (lsm_mathml_unit_strings));
 }
 
 static const char *lsm_mathml_font_style_strings[] = {
 	"normal",
-	"italic",
-	""
+	"italic"
 };
 
 const char *
 lsm_mathml_font_style_to_string (LsmMathmlFontStyle font_style)
 {
-	return lsm_mathml_font_style_strings[CLAMP (font_style, 0, LSM_MATHML_FONT_STYLE_ERROR)];
+	if (font_style < 0 || font_style > LSM_MATHML_FONT_STYLE_ITALIC)
+		return NULL;
+
+	return lsm_mathml_font_style_strings[font_style];
 }
 
 LsmMathmlFontStyle
 lsm_mathml_font_style_from_string (const char *string)
 {
-	return lsm_mathml_value_from_string (string, lsm_mathml_font_style_strings,
-					     G_N_ELEMENTS (lsm_mathml_font_style_strings));
+	return lsm_enum_value_from_string (string, lsm_mathml_font_style_strings,
+					   G_N_ELEMENTS (lsm_mathml_font_style_strings));
 }
 
 static const char *lsm_mathml_font_weight_strings[] = {
 	"normal",
-	"bold",
-	""
+	"bold"
 };
 
 const char *
 lsm_mathml_font_weight_to_string (LsmMathmlFontWeight font_weight)
 {
-	return lsm_mathml_font_weight_strings[CLAMP (font_weight, 0, LSM_MATHML_FONT_WEIGHT_ERROR)];
+	if (font_weight < 0 || font_weight > LSM_MATHML_FONT_WEIGHT_BOLD)
+		return NULL;
+
+	return lsm_mathml_font_weight_strings[font_weight];
 }
 
 LsmMathmlFontWeight
 lsm_mathml_font_weight_from_string (const char *string)
 {
-	return lsm_mathml_value_from_string (string, lsm_mathml_font_weight_strings,
-					     G_N_ELEMENTS (lsm_mathml_font_weight_strings));
+	return lsm_enum_value_from_string (string, lsm_mathml_font_weight_strings,
+					   G_N_ELEMENTS (lsm_mathml_font_weight_strings));
 }
 
 static const char *lsm_mathml_variant_strings[] = {
@@ -184,14 +185,17 @@ static const char *lsm_mathml_variant_strings[] = {
 const char *
 lsm_mathml_variant_to_string (LsmMathmlVariant variant)
 {
-	return lsm_mathml_variant_strings[CLAMP (variant, 0, LSM_MATHML_VARIANT_MONOSPACE)];
+	if (variant < 0 || variant > LSM_MATHML_VARIANT_MONOSPACE)
+		return NULL;
+
+	return lsm_mathml_variant_strings[variant];
 }
 
 LsmMathmlVariant
 lsm_mathml_variant_from_string (const char *string)
 {
-	return lsm_mathml_value_from_string (string, lsm_mathml_variant_strings,
-					  G_N_ELEMENTS (lsm_mathml_variant_strings));
+	return lsm_enum_value_from_string (string, lsm_mathml_variant_strings,
+					   G_N_ELEMENTS (lsm_mathml_variant_strings));
 }
 
 void
@@ -343,14 +347,17 @@ static const char *lsm_mathml_form_strings[] = {
 const char *
 lsm_mathml_form_to_string (LsmMathmlForm form)
 {
-	return lsm_mathml_form_strings[CLAMP (form, 0, LSM_MATHML_FORM_INFIX)];
+	if (form < 0 || form > LSM_MATHML_FORM_INFIX)
+		return NULL;
+
+	return lsm_mathml_form_strings[form];
 }
 
 LsmMathmlForm
 lsm_mathml_form_from_string (const char *string)
 {
-	return lsm_mathml_value_from_string (string, lsm_mathml_form_strings,
-					  G_N_ELEMENTS (lsm_mathml_form_strings));
+	return lsm_enum_value_from_string (string, lsm_mathml_form_strings,
+					   G_N_ELEMENTS (lsm_mathml_form_strings));
 }
 
 static const char *lsm_mathml_row_align_strings[] = {
@@ -364,14 +371,17 @@ static const char *lsm_mathml_row_align_strings[] = {
 const char *
 lsm_mathml_row_align_to_string (LsmMathmlRowAlign row_align)
 {
-	return lsm_mathml_row_align_strings[CLAMP (row_align, 0, LSM_MATHML_ROW_ALIGN_AXIS)];
+	if (row_align < 0 || row_align > LSM_MATHML_ROW_ALIGN_AXIS)
+		return NULL;
+
+	return lsm_mathml_row_align_strings[row_align];
 }
 
 LsmMathmlRowAlign
 lsm_mathml_row_align_from_string (const char *string)
 {
-	return lsm_mathml_value_from_string (string, lsm_mathml_row_align_strings,
-					  G_N_ELEMENTS (lsm_mathml_row_align_strings));
+	return lsm_enum_value_from_string (string, lsm_mathml_row_align_strings,
+					   G_N_ELEMENTS (lsm_mathml_row_align_strings));
 }
 
 static const char *lsm_mathml_column_align_strings[] = {
@@ -383,14 +393,17 @@ static const char *lsm_mathml_column_align_strings[] = {
 const char *
 lsm_mathml_column_align_to_string (LsmMathmlColumnAlign column_align)
 {
-	return lsm_mathml_column_align_strings[CLAMP (column_align, 0, LSM_MATHML_COLUMN_ALIGN_RIGHT)];
+	if (column_align < 0 || column_align > LSM_MATHML_COLUMN_ALIGN_RIGHT)
+		return NULL;
+
+	return lsm_mathml_column_align_strings[column_align];
 }
 
 LsmMathmlColumnAlign
 lsm_mathml_column_align_from_string (const char *string)
 {
-	return lsm_mathml_value_from_string (string, lsm_mathml_column_align_strings,
-					  G_N_ELEMENTS (lsm_mathml_column_align_strings));
+	return lsm_enum_value_from_string (string, lsm_mathml_column_align_strings,
+					   G_N_ELEMENTS (lsm_mathml_column_align_strings));
 }
 
 static const char *lsm_mathml_line_strings[] = {
@@ -402,12 +415,15 @@ static const char *lsm_mathml_line_strings[] = {
 const char *
 lsm_mathml_line_to_string (LsmMathmlLine line)
 {
-	return lsm_mathml_line_strings [CLAMP (line, 0, LSM_MATHML_LINE_DASHED)];
+	if (line < 0 || line > LSM_MATHML_LINE_DASHED)
+		return NULL;
+
+	return lsm_mathml_line_strings [line];
 }
 
 LsmMathmlLine
 lsm_mathml_line_from_string (const char *string)
 {
-	return lsm_mathml_value_from_string (string, lsm_mathml_line_strings,
-					  G_N_ELEMENTS (lsm_mathml_line_strings));
+	return lsm_enum_value_from_string (string, lsm_mathml_line_strings,
+					   G_N_ELEMENTS (lsm_mathml_line_strings));
 }
