@@ -1,19 +1,20 @@
 /*
  * Copyright © 2009 Emmanuel Pacaud
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
+ * You should have received a copy of the GNU Lesser General
+ * Public License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
+ * Boston, MA 02111-1307, USA.
  *
  * Author:
  * 	Emmanuel Pacaud <emmanuel@gnome.org>
@@ -27,6 +28,12 @@
 
 G_BEGIN_DECLS
 
+typedef struct {
+	LsmSvgMatrix transform;
+	LsmSvgPatternUnits units;
+	LsmSvgSpreadMethod spread_method;
+} LsmSvgGradientElementAttributes;
+
 #define LSM_TYPE_SVG_GRADIENT_ELEMENT             (lsm_svg_gradient_element_get_type ())
 #define LSM_SVG_GRADIENT_ELEMENT(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), LSM_TYPE_SVG_GRADIENT_ELEMENT, LsmSvgGradientElement))
 #define LSM_SVG_GRADIENT_ELEMENT_CLASS(klass)     (G_TYPE_CHECK_CLASS_CAST ((klass), LSM_TYPE_SVG_GRADIENT_ELEMENT, LsmSvgGradientElementClass))
@@ -50,7 +57,7 @@ struct _LsmSvgGradientElement {
 struct _LsmSvgGradientElementClass {
 	LsmSvgElementClass  element_class;
 
-	void (*create_gradient)	(LsmSvgElement *self, LsmSvgView *view);
+	LsmSvgGradientElement * (*create_gradient)	(LsmSvgElement *self, LsmSvgView *view);
 };
 
 GType lsm_svg_gradient_element_get_type (void);
